==> mysql-5.6.50.tar.gz: mysql-5.6.50/storage/ndb/include/kernel/signaldata/InvalidateNodeLCPReq.hpp <==
/*
   Copyright (C) 2003, 2005, 2006 MySQL AB
    All rights reserved. Use is subject to license terms.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is also distributed with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have included with MySQL.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/

#ifndef INVALIDATE_NODE_LCP_REQ_HPP
#define INVALIDATE_NODE_LCP_REQ_HPP

/**
 * This signal is sent from the master DIH to all DIHs
 * when a node is starting without filesystem.
 *
 * All DIHs must then "forgett" that the starting node has 
 * performed LCP
 *
 * @see StartPermReq
 */
class InvalidateNodeLCPReq {
  
  /**
   * Sender/Receiver
   */
  friend class Dbdih;
  
  Uint32 startingNodeId;

public:
  STATIC_CONST( SignalLength = 1 );
};

#endif

==> mysql-8.0.26.tar.gz: mysql-8.0.26/storage/ndb/include/kernel/signaldata/InvalidateNodeLCPReq.hpp <==
/*
   Copyright (c) 2003, 2021, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is also distributed with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have included with MySQL.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/

#ifndef INVALIDATE_NODE_LCP_REQ_HPP
#define INVALIDATE_NODE_LCP_REQ_HPP

#define JAM_FILE_ID 76


/**
 * This signal is sent from the master DIH to all DIHs
 * when a node is starting without filesystem.
 *
 * All DIHs must then "forgett" that the starting node has 
 * performed LCP
 *
 * @see StartPermReq
 */
class InvalidateNodeLCPReq {
  
  /**
   * Sender/Receiver
   */
  friend class Dbdih;
  
  Uint32 startingNodeId;

public:
  static constexpr Uint32 SignalLength = 1;
};


#undef JAM_FILE_ID

#endif
